@@ -8,7 +8,7 @@ from django.contrib.admin.sites import NotRegistered
 from django.views.generic.simple import direct_to_template
 
 from mezzanine.settings import ADMIN_REMOVAL, CONTENT_MEDIA_PATH, \
-    CONTENT_MEDIA_URL, PACKAGE_NAME_FILEBROWSER, PACKAGE_NAME_GRAPPELLI
+    CONTENT_MEDIA_URL
 
 urlpatterns = patterns("",
     url("^admin_keywords_submit/$", 
@@ -34,15 +34,17 @@ for model in ADMIN_REMOVAL:
 
 # Pairs of optional app names and their urlpatterns.
 OPTIONAL_APP_PATTERNS = (
-    (PACKAGE_NAME_FILEBROWSER, patterns("",
-        ("^admin/filebrowser/", include("%s.urls" % PACKAGE_NAME_FILEBROWSER)),
+    (settings.PACKAGE_NAME_FILEBROWSER, patterns("",
+        ("^admin/filebrowser/", include("%s.urls" % 
+            settings.PACKAGE_NAME_FILEBROWSER)),
         ("^%s/(?P<path>.*)$" % getattr(settings, 
             "FILEBROWSER_URL_FILEBROWSER_MEDIA", "").strip("/"), 
             "django.views.static.serve", {'document_root': 
             getattr(settings, "FILEBROWSER_PATH_FILEBROWSER_MEDIA", "")}),
     )),
-    (PACKAGE_NAME_GRAPPELLI, patterns("",
-        ("^grappelli/", include("%s.urls" % PACKAGE_NAME_GRAPPELLI)),
+    (settings.PACKAGE_NAME_GRAPPELLI, patterns("",
+        ("^grappelli/", include("%s.urls" % 
+            settings.PACKAGE_NAME_GRAPPELLI)),
         ("^%s/admin/(?P<path>.*)$" % urlsplit(settings.ADMIN_MEDIA_PREFIX
             ).path.strip("/").split("/")[0], "django.views.static.serve", 
             {'document_root': getattr(settings, "GRAPPELLI_MEDIA_PATH", "")}),
